"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.aliMaterialRenderer = void 0;
const tableMdastBuilder_1 = require("../../tableMdastBuilder");
const mdast_builder_1 = require("mdast-builder");
const y18n = require("y18n");
const path = require("path");
const isEnumType = (type) => type.name === 'enum' && Array.isArray(type.value);
/**
 * alibaba materials style renderer
 * @see https://yuque.antfin-inc.com/mo/spec/spec-materials#CZiWi
 * @example
 * ``` md
 * ### Column

 * Form column.

 * | Param              | Description              | Type                                | Enum                            | Default |
 * | ------------------ | ------------------------ | ----------------------------------- | ------------------------------- | ------- |
 * | prop1              | prop1 description        | `string`                            |                                 | "red"   |
 * | prop2 _(required)_ | prop2 description        | `number`                            |                                 |         |
 * | prop3 _(required)_ | prop3 description a \| b | `() => void`                        |                                 |         |
 * | prop4 _(required)_ | prop4 description 中文   | `"option1" | "option2" | "option3"` | "option1", "option2", "option3" |         |
 * ```
 */
exports.aliMaterialRenderer = (componentDoc, { language } = {}) => {
    const { __ } = y18n({
        locale: language || 'en_US',
        directory: path.resolve(__dirname, '..', '..', '..', 'locales', 'aliMaterialRenderer'),
    });
    return [
        mdast_builder_1.heading(3, mdast_builder_1.text(componentDoc.displayName)),
        mdast_builder_1.text(componentDoc.description),
        tableMdastBuilder_1.tableMdastBuilder(Object.values(componentDoc.props), [
            {
                title: __('Param'),
                render: (vo) => vo.required
                    ? [mdast_builder_1.text(vo.name), mdast_builder_1.text(' '), mdast_builder_1.emphasis(mdast_builder_1.text(`(${__('required')})`))]
                    : vo.name,
            },
            {
                title: __('Description'),
                render: (vo) => vo.description,
            },
            {
                title: __('Type'),
                render: (vo) => mdast_builder_1.inlineCode(isEnumType(vo.type) ? vo.type.raw : vo.type.name),
            },
            {
                title: __('Enum'),
                render: (vo) => isEnumType(vo.type) ? vo.type.value.map((e) => e.value).join(', ') : '',
            },
            {
                title: __('Default'),
                render: (vo) => { var _a; return ((_a = vo.defaultValue) === null || _a === void 0 ? void 0 : _a.value) || ''; },
            },
        ]),
    ];
};
//# sourceMappingURL=index.js.map